@@ -14,6 +14,7 @@ from nebula3.common.ttypes import (
     Date,
     DateTime,
     Duration,
+    Edge,
     ErrorCode,
     NList,
     NMap,
@@ -21,7 +22,9 @@ from nebula3.common.ttypes import (
     NullType,
     Time,
     Value,
+    Vertex,
 )
+
 from nebula3.data.DataObject import (
     DataSetWrapper,
     DateTimeWrapper,
@@ -381,6 +384,134 @@ class TesValueWrapper(TestBaseCase):
         ]
         assert list_val == expect_result
 
+    def test_cast_primitive(self):
+        # Test casting for primitive types
+        def _cast_node(node: Vertex):
+            return {
+                "vid": node.get_id().cast(),
+                "tags": {
+                    tag_name: node.properties(tag_name) for tag_name in node.tags()
+                },
+            }
+
+        def _cast_relationship(edge: Edge):
+            return {
+                "src": edge.start_vertex_id().cast(),
+                "dst": edge.end_vertex_id().cast(),
+                "type": edge.edge_name(),
+                "rank": edge.ranking(),
+                "props": edge.properties(),
+            }
+
+        # Test boolean
+        bool_val = ttypes.Value(bVal=True)
+        assert ValueWrapper(bool_val).cast_primitive() is True
+
+        # Test integer
+        int_val = ttypes.Value(iVal=42)
+        assert ValueWrapper(int_val).cast_primitive() == 42
+
+        # Test double
+        double_val = ttypes.Value(fVal=3.14)
+        assert ValueWrapper(double_val).cast_primitive() == 3.14
+
+        # Test string
+        string_val = ttypes.Value(sVal=b"hello")
+        assert ValueWrapper(string_val).cast_primitive() == "hello"
+
+        # Test null
+        null_val = ttypes.Value(nVal=ttypes.NullType.__NULL__)
+        assert ValueWrapper(null_val).cast_primitive() is None
+
+        # Test node
+        node_val = ttypes.Value(vVal=self.get_vertex_value(b"Tom"))
+        node = ValueWrapper(node_val).as_node()
+        assert ValueWrapper(node_val).cast_primitive() == {
+            "vid": node.get_id().cast(),
+            "tags": {tag_name: node.properties(tag_name) for tag_name in node.tags()},
+        }
+
+        # Test relationship
+        relationship_val = ttypes.Value(eVal=self.get_edge_value(b"Tom", b"Lily"))
+        edge = ValueWrapper(relationship_val).as_relationship()
+        assert ValueWrapper(relationship_val).cast_primitive() == {
+            "src": edge.start_vertex_id().cast(),
+            "dst": edge.end_vertex_id().cast(),
+            "type": edge.edge_name(),
+            "rank": edge.ranking(),
+            "props": edge.properties(),
+        }
+
+        # Test path
+        path_val = ttypes.Value(pVal=self.get_path_value(b"Tom"))
+        path_raw = ValueWrapper(path_val)
+        path = path_raw.as_path()
+        path_primitive = path_raw.cast_primitive()
+        assert path_primitive == {
+            "path_str": path.__repr__(),
+            "start_node": _cast_node(path.start_node()),
+            "edges": [_cast_relationship(x) for x in path.relationships()],
+            "nodes": [_cast_node(x) for x in path.nodes()],
+        }
+
+        # Test geography
+        geography_val = ttypes.Value(ggVal=self.get_geography_value(3.0, 5.2))
+        geography_raw = ValueWrapper(geography_val)
+        geography = geography_raw.as_geography()
+        assert geography_raw.cast_primitive() == geography.__repr__()
+
+        # Test duration
+        duration_val = ttypes.Value(duVal=Duration(86400, 3000, 12))
+        duration_raw = ValueWrapper(duration_val)
+        duration = duration_raw.as_duration()
+        assert duration_raw.cast_primitive() == duration.__repr__()
+
+        # Test list
+        list_val = ttypes.Value()
+        str_val1 = ttypes.Value()
+        str_val1.set_sVal(b"word")
+        str_val2 = ttypes.Value()
+        str_val2.set_sVal(b"car")
+        val_list = NList()
+        val_list.values = [str_val1, str_val2]
+        list_val.set_lVal(val_list)
+        list_raw = ValueWrapper(list_val)
+        assert list_raw.cast_primitive() == [
+            ValueWrapper(str_val1).cast_primitive(),
+            ValueWrapper(str_val2).cast_primitive(),
+        ]
+
+        # Test set
+        set_val = ttypes.Value()
+        tmp_set_val = NSet()
+        tmp_set_val.values = set()
+        tmp_set_val.values.add(str_val1)
+        tmp_set_val.values.add(str_val2)
+        set_val.set_uVal(tmp_set_val)
+        set_raw = ValueWrapper(set_val)
+        assert set_raw.cast_primitive() == {
+            ValueWrapper(str_val1).cast_primitive(),
+            ValueWrapper(str_val2).cast_primitive(),
+        }
+
+        # Test map
+        map_val = ttypes.Value()
+        tmp_map_val = NMap()
+        tmp_map_val.kvs = {b"a": str_val1, b"b": str_val2}
+        map_val.set_mVal(tmp_map_val)
+        map_raw = ValueWrapper(map_val)
+        assert map_raw.cast_primitive() == {
+            "a": ValueWrapper(str_val1).cast_primitive(),
+            "b": ValueWrapper(str_val2).cast_primitive(),
+        }
+
+        # Test time
+        time_val = ttypes.Value()
+        time_val.set_tVal(Time(10, 10, 10, 10000))
+        time_raw = ValueWrapper(time_val)
+        time = time_raw.as_time()
+        assert time_raw.cast_primitive() == time.get_local_time_str()
+
     def test_as_time(self):
         time = Time()
         time.hour = 10
